/*
**************************************************************************
                                 description
                             --------------------
    copyright            : (C) 2002 by Luis Carvalho
    email                : lpassos@mail.telepac.pt
**************************************************************************

**************************************************************************
*                                                                        *
*  This program is free software; you can redistribute it and/or modify  *
*  it under the terms of the GNU General Public License as published by  *
*  the Free Software Foundation; either version 2 of the License, or     *
*  (at your option) any later version.                                   *
*                                                                        *
**************************************************************************/


#include "pmlibraryobject.h"
#include "pmlibraryobjectpreview.h"
#include "pmdialogeditbase.h"

#include <qlabel.h>
#include <qtextedit.h>
#include <qlayout.h>
#include <qpixmap.h>
#include <qimage.h>
#include <qframe.h>

#include <kurl.h>
#include <klocale.h>
#include <kdialog.h>

PMLibraryObjectPreview::PMLibraryObjectPreview( QWidget* parent ) :
   KPreviewWidgetBase( parent )
{
   setMaximumSize( 400, 400 );
   QVBoxLayout* vl = new QVBoxLayout( this, KDialog::spacingHint( ) );

   m_pPreviewPixmap = new QFrame( this );
   m_pPreviewPixmap->setFrameStyle( QFrame::Box | QFrame::Sunken );
   m_pPreviewPixmap->setMinimumSize( PMDialogEditBase::previewSize( ), PMDialogEditBase::previewSize( ) );
   m_pPreviewPixmap->setMaximumSize( PMDialogEditBase::previewSize( ), PMDialogEditBase::previewSize( ) );
   m_pPreviewPixmap->setMidLineWidth( 1 );
   QHBoxLayout* hl = new QHBoxLayout( vl );
   hl->addStretch( 1 );
   hl->addWidget( m_pPreviewPixmap );
   hl->addStretch( 1 );

   QGridLayout* gl = new QGridLayout( vl, 4, 2 );
   gl->setColStretch( 1, 1 );
   QLabel* lbl = new QLabel( i18n( "Name: " ), this );
   m_pName = new QLabel( "", this );
   m_pName->setAlignment( Qt::AlignLeft );
   gl->addWidget( lbl, 0, 0 );
   gl->addWidget( m_pName, 0, 1 );
   lbl = new QLabel( i18n( "Type: " ), this );
   m_pType = new QLabel( "", this );
   m_pType->setAlignment( Qt::AlignLeft );
   gl->addWidget( lbl, 1, 0 );
   gl->addWidget( m_pType, 2, 1 );

   lbl = new QLabel( i18n( "Description: " ), this );
   lbl->setAlignment( Qt::AlignTop );
   m_pDescription = new QLabel( "", this );
   m_pDescription->setAlignment( Qt::AlignTop  | Qt::AlignLeft | 
                                 Qt::WordBreak | Qt::DontClip );
   gl->addWidget( lbl, 2, 0 );
   gl->addWidget( m_pDescription, 2, 1 );

   vl->addStretch( 1 );
}

void PMLibraryObjectPreview::showPreview( const KURL& u )
{
   if( u.isLocalFile( ) )
   {
      PMLibraryObject aux( u );
      QPixmap p;

      if( aux.preview( ) )
         p.convertFromImage( aux.preview( )->smoothScale( PMDialogEditBase::previewSize( ), 
                                                          PMDialogEditBase::previewSize( ) ) );
      
      m_pName->setText( aux.name( ) );
      m_pType->setText( aux.type( ) );
      m_pDescription->setText( aux.description( ) );
      m_pPreviewPixmap->setPaletteBackgroundPixmap( p );
   }
}

void PMLibraryObjectPreview::clearPreview( )
{
   m_pName->setText( "" );
   m_pType->setText( "" );
   m_pDescription->setText( "" );
   m_pPreviewPixmap->unsetPalette( );
}

#include "pmlibraryobjectpreview.moc"
